==> 3.5.12-core.tar: kdewebdev/quanta/parts/kafka/domtreeview.h <==
/***************************************************************************
                               domtreeview.cpp
                             -------------------

    copyright            : (C) 2001 - The Kafka Team
    email                : kde-kafka@master.kde.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DOMTREEVIEW_H
#define DOMTREEVIEW_H

#include "kafkacommon.h"

#ifdef HEAVY_DEBUG
#include <klistview.h>
#include <kdebug.h>
#include <tqlistview.h>
#include <tqptrdict.h>
#include <dom/dom_core.h>
#include <tqdialog.h>

class TQString;
class TQGridLayout;

/**
 * This class is very useful to see the DOM tree in a KListView
 */

class DOMTreeView : public KListView
{
    Q_OBJECT
    public:
	DOMTreeView(TQWidget *parent, KHTMLPart *part, const char * name = 0);
	~DOMTreeView();
        void setTitle(const TQString &str);
	void recursive(const DOM::Node &pNode, const DOM::Node &node);

    signals:
	void sigNodeClicked(const DOM::Node &);

    public slots:
	void showTree(const DOM::Node &pNode);

    protected slots:
	void slotItemClicked(TQListViewItem *);

    private:
	TQString title;
	TQListViewItem *titleItem;
	TQPtrDict<TQListViewItem> m_itemdict;
	TQPtrDict<DOM::Node> m_nodedict;
	DOM::Node document;
	KHTMLPart *part;

};

class KafkaDOMTreeDialog : public QDialog
{
	Q_OBJECT
public:
	KafkaDOMTreeDialog(TQWidget *parent = 0, KHTMLPart *part = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
	~KafkaDOMTreeDialog();
	DOMTreeView *domview;
	TQGridLayout *DialogLayout;
};

#endif
#endif

==> 3.5.13-core.tar: kdewebdev/quanta/parts/kafka/domtreeview.h <==
/***************************************************************************
                               domtreeview.cpp
                             -------------------

    copyright            : (C) 2001 - The Kafka Team
    email                : kde-kafka@master.kde.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DOMTREEVIEW_H
#define DOMTREEVIEW_H

#include "kafkacommon.h"

#ifdef HEAVY_DEBUG
#include <klistview.h>
#include <kdebug.h>
#include <tqlistview.h>
#include <tqptrdict.h>
#include <dom/dom_core.h>
#include <tqdialog.h>

class TQString;
class TQGridLayout;

/**
 * This class is very useful to see the DOM tree in a KListView
 */

class DOMTreeView : public KListView
{
    Q_OBJECT
  TQ_OBJECT
    public:
	DOMTreeView(TQWidget *parent, KHTMLPart *part, const char * name = 0);
	~DOMTreeView();
        void setTitle(const TQString &str);
	void recursive(const DOM::Node &pNode, const DOM::Node &node);

    signals:
	void sigNodeClicked(const DOM::Node &);

    public slots:
	void showTree(const DOM::Node &pNode);

    protected slots:
	void slotItemClicked(TQListViewItem *);

    private:
	TQString title;
	TQListViewItem *titleItem;
	TQPtrDict<TQListViewItem> m_itemdict;
	TQPtrDict<DOM::Node> m_nodedict;
	DOM::Node document;
	KHTMLPart *part;

};

class KafkaDOMTreeDialog : public TQDialog
{
	Q_OBJECT
  TQ_OBJECT
public:
	KafkaDOMTreeDialog(TQWidget *parent = 0, KHTMLPart *part = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
	~KafkaDOMTreeDialog();
	DOMTreeView *domview;
	TQGridLayout *DialogLayout;
};

#endif
#endif
